@@ -5,8 +5,12 @@ export default {
     let found;
 
     if (typeof window !== 'undefined') {
-      let query = window.location.search.substring(1);
-      let params = query.split('&');
+      let search = window.location.search;
+      if (!window.location.search && window.location.hash && window.location.hash.indexOf('?') > -1) {
+        search = window.location.hash.substring(window.location.hash.indexOf('?'))
+      }
+      const query = search.substring(1);
+      const params = query.split('&');
       for (let i=0; i<params.length; i++) {
         let pos = params[i].indexOf('=');
         if (pos > 0) {
